@@ -16,7 +16,7 @@ Usage::
     session_client: BackupClient = session.client("backup")
     ```
 """
-from mypy_boto3_backup.client import BackupClient, BackupClient as Client
+from mypy_boto3_backup.client import BackupClient as Client, BackupClient
 
 
 __all__ = ("BackupClient", "Client")
